package com.diagbot.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.diagbot.dto.GetQuestionInfoDTO;
import com.diagbot.entity.ModuleInfo;
import com.diagbot.enums.IsDeleteEnum;
import com.diagbot.exception.CommonErrorCode;
import com.diagbot.exception.CommonException;
import com.diagbot.service.impl.ModuleInfoServiceImpl;
import com.diagbot.util.BeanUtil;
import com.diagbot.util.DateUtil;
import com.diagbot.util.StringUtil;
import com.diagbot.util.UserUtils;
import com.diagbot.vo.AddModuleInfoVO;
import com.diagbot.vo.ModuleGetQuestionInfoVO;
import com.diagbot.vo.UpdateModuleInfoVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Arrays;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:zhoutg
 * @time: 2018/11/23 11:37
 */
@Component
public class ModuleInfoFacade extends ModuleInfoServiceImpl {


    @Autowired
    ModuleDetailFacade moduleDetailFacade;
    @Autowired
    QuestionInfoFacade questionInfoFacade;

    /**
     * 根据id删除标签模板
     *
     * @param ids
     * @return
     */
    public Boolean deleteByIdsFac(String ids) {
        if (StringUtil.isEmpty(ids)) {
            return true;
        }
        Map paramMap = new HashMap<>();
        paramMap.put("delete", IsDeleteEnum.Y.getKey());
        paramMap.put("ids", Arrays.asList(ids.split(",")));
        paramMap.put("gmtModified", DateUtil.now());
        paramMap.put("modifier", UserUtils.getCurrentPrincipleID());

        //删除模板
        this.deleteByIds(paramMap);

        //删除明细表
        moduleDetailFacade.deleteByModuleIdFac(paramMap);
        return true;
    }

    /**
     * 添加模板
     *
     * @param addModulInfoVO
     * @return
     */
    public Boolean saveModuleInfo(AddModuleInfoVO addModulInfoVO){
/*        String userId = UserUtils.getCurrentPrincipleID();*/
        Date now = DateUtil.now();
        //查询该模板是否添加过
        QueryWrapper<ModuleInfo> moduleInfoQueryWrapper = new QueryWrapper<>();
        moduleInfoQueryWrapper.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("name",addModulInfoVO.getName());
        ModuleInfo moduleInfos = this.getOne(moduleInfoQueryWrapper);
        if(null != moduleInfos){
            throw new CommonException(CommonErrorCode.INSERT_DATA_FAILED,
                    "模板名重复，请勿重复添加");
        }
        ModuleInfo moduleInfo = new ModuleInfo();
        BeanUtil.copyProperties(addModulInfoVO,moduleInfo);
        moduleInfo.setCreator("1"/*userId*/);
        moduleInfo.setModifier("1"/*userId*/);
        moduleInfo.setGmtCreate(now);
        moduleInfo.setGmtModified(now);
        this.save(moduleInfo);
        Long moduleId = moduleInfo.getId();
        return moduleDetailFacade.saveOrUpdateInfos(addModulInfoVO,moduleId);
    }
    /**
     * 修改模板
     *
     * @param updateModuleInfoVO
     * @return
     */
    public Boolean updateModuleInfo(UpdateModuleInfoVO updateModuleInfoVO){
        /*        String userId = UserUtils.getCurrentPrincipleID();*/
        UpdateWrapper<ModuleInfo> moduleInfoUpdateWrapper = new UpdateWrapper<>();
        moduleInfoUpdateWrapper.eq("is_deleted", IsDeleteEnum.N.getKey())
                .eq("id",updateModuleInfoVO.getId())
                .set("name",updateModuleInfoVO.getName())
                .set("type",updateModuleInfoVO.getType())
                .set("modifier","1")
                .set("gmt_modified",DateUtil.now());
        this.update(new ModuleInfo(),moduleInfoUpdateWrapper);
        AddModuleInfoVO addModuleInfoVO = new AddModuleInfoVO();
        BeanUtil.copyProperties(updateModuleInfoVO,addModuleInfoVO);
        return moduleDetailFacade.saveOrUpdateInfos(addModuleInfoVO,updateModuleInfoVO.getId());
    }

    /**
     * 获取标签池信息
     *
     * @param moduleGetQuestionInfoVO
     * @return
     */
    public List<GetQuestionInfoDTO> getQuestionInfos(ModuleGetQuestionInfoVO moduleGetQuestionInfoVO){
        List<GetQuestionInfoDTO> getQuestionInfoDTOS = questionInfoFacade.moduleGetQuestiongInfoByName(moduleGetQuestionInfoVO);
        return getQuestionInfoDTOS;
    }
}
